import pool from "@/utils/db";
import { NextResponse } from "next/server";

export async function GET() {
  const runResults = await pool
    .query<{
      id: number;
      name: string;
      created_at: Date;
    }>(`select * from runs;`)
    .then((r) => r.rows);

  const testResults = await pool
    .query<{
      id: number;
      run_id: number;
      test_name: string;
      path: string;
      duration: number;
      success?: boolean;
      pending: boolean;
      created_at: Date; 
    }>(`select * from test_runs;`)
    .then((r) => r.rows);

  const formatted = runResults.map((run) => {
    const children = testResults.filter(
      (test) => test !== null && test.run_id === run.id
    );
    const totalDuration = children.reduce(
      (n, child) => n + Number(child.duration),
      0
    );
    return {
      run_id: run.id,
      run_name: run.name,
      date: run.created_at,
      totalseconds: totalDuration,
      success_count: children.filter((test) => test.success).length,
      failure_count: children.filter((test) => !test.success).length,
      children: children.map((test) => ({
        ...test,
        duration: Number(test.duration),
      })),
    };
  });
  return NextResponse.json(formatted);
}
