import { NextResponse } from "next/server";
import pool from "@/utils/db";

export async function POST(request: Request) {
  let runId;
  try {
    let {runName, testId, testName, path,duration, success, runId: passedRunId} = await request.json();
    if (!passedRunId) {
      const res = await pool
        .query(
          `WITH new_run AS ( INSERT INTO runs (name) VALUES ($1) RETURNING id)
            SELECT id FROM new_run;`,
          [runName],
        )
        .then((r) => r.rows[0].id);
      return NextResponse.json({ runId: res });
    }
    if (!testId) {
      const res = await pool.query(`INSERT INTO test_runs (run_id, test_name, path)
         VALUES ($1, $2, $3) returning id`,
        [passedRunId, testName, path],
      );
      return NextResponse.json({
        testId: res.rows[0].id,
      });
    }
    if (testId) {
      if (duration) {
        await pool.query(
          `UPDATE test_runs SET pending = false, success = $3, duration = $2 WHERE id = $1;`,
          [testId, duration, success],
        );
        return NextResponse.json({ testId });
      }
    }
    return NextResponse.json({ runId });
  } catch (error) {
    console.error("Error creating run:", error);
    return NextResponse.json(
      // @ts-ignore
      {error: "Failed to create run", message: error.message, detail: error.detail},
      { status: 500 },
    );
  }
}
